@@ -213,7 +213,7 @@ unallocRecordList(RecordList rl)
 
 #define SIZERECORD(flags) \
 	((flags & R_DUPLICATE) ? offsetof(struct record, buffer[0]) : \
-	                         offsetof(struct record, references)) \
+				 offsetof(struct record, references)) \
 
 #define dataRecord(r) ((char *)addPointer(r, SIZERECORD(r->flags)))
 
@@ -548,7 +548,7 @@ compile_term_to_heap(DECL_LD term_agenda *agenda, CompileInfo info)
 	      addOpCode(info, PL_TYPE_INTEGER);
 	      addInt64(info, n.value.i);
 	      break;
-#ifdef O_GMP
+#if O_BIGNUM
 	    case V_MPZ:
 	      addOpCode(info, PL_REC_MPZ);
 	      addMPZToBuffer((Buffer)&info->code, n.value.mpz);
@@ -1200,7 +1200,7 @@ typedef struct
   uint		nvars;			/* Variables seen */
   uint		dicts;			/* # dicts found */
   TmpBuffer	avars;			/* Values stored for attvars */
-  Word	        vars_buf[MAX_FAST_VARS];
+  Word		vars_buf[MAX_FAST_VARS];
 } copy_info, *CopyInfo;
 
 static void skipSizeInt(CopyInfo b);
@@ -1433,7 +1433,7 @@ copy_record(DECL_LD Word p, CopyInfo b)
 	*b->gstore++ = mkIndHdr(WORDS_PER_PLINT, TAG_INTEGER);
 	continue;
       }
-#ifdef O_GMP
+#if O_BIGNUM
       case PL_REC_MPZ:
 	b->data = loadMPZFromCharp(b->data, p, &b->gstore);
 	continue;
@@ -1712,7 +1712,7 @@ scanAtomsRecord(CopyInfo b, void (*func)(atom_t a))
       { skipLong(b);
 	continue;
       }
-#ifdef O_GMP
+#ifdef O_BIGNUM
       case PL_REC_MPZ:
 	b->data = skipMPZOnCharp(b->data);
 	continue;
@@ -2222,6 +2222,8 @@ PRED_IMPL("recorded", va, recorded, PL_FA_NONDETERMINISTIC)
 	PL_LOCK(L_RECORD);
 	rl->references++;
 	state->r = rl->firstRecord;
+	if ( true(state->r->record, R_ERASED) )
+	  advance_state(state);
       } else
       { return FALSE;
       }
